@@ -1,4 +1,5 @@
 from .excel_module import get_df,create_dataframe,get_row,get_cell_value,gpd
+from .file_utils import safe_excel_save
 from .functions import haversine
 from shapely.geometry import Polygon,MultiPolygon
 import os
@@ -15,8 +16,7 @@ class landManager:
         self.default_polygon= default_polygon
         for directory_name,directory_path in directory_js.items():
             self.file_manager[directory_name] = {} 
-            self.ext_js = {"shp":'.shp', "prj":'.prj', "cpg":'.cpg', "dbf":'.dbf', "shx":'.shx'}
-
+            self.ext_js = {"shp":'.shp', "prj":'.prj', "cpg":'.cpg', "dbf":'.dbf', "shx":'.shx','geojson':'.geojson'}
             for file_item in os.listdir(directory_path):
                 item_path = os.path.join(directory_path,file_item)
                 self.file_manager[directory_name][os.path.splitext(file_item)[-1][1:]] = item_path
@@ -24,6 +24,7 @@ class landManager:
                 gdf=self.get_contents(directory_name,file_type='shp')
                 if isinstance(gdf,gpd.GeoDataFrame):
                     self.default_polygon = self.get_polygon(gdf,column=column,value=value,index=index)
+            self.check_geo_json(directory_name)
     @staticmethod
     def get_instance(directory_js=None):
         if landManager._instance is None:
@@ -40,6 +41,20 @@ class landManager:
             gdf,index = get_row(target_value=value,column_name=column,df=gdf)
         if isinstance(gdf,gpd.GeoDataFrame):
             return get_cell_value(gdf,'geometry',index)
+    def check_geo_json(self,dir_name):
+        geoJsonPath = self.file_manager.get(dir_name,{}).get('geojson')
+        if geoJsonPath == None or not os.path.isfile(geoJsonPath):
+            shp_file = self.file_manager.get(dir_name,{}).get('shp')
+            if shp_file and os.path.isfile(shp_file):
+                directory = os.path.dirname(shp_file)
+                baseName = os.path.dirname(shp_file)
+                fileName,ext = os.path.splitext(baseName)
+                gdf = self.get_contents(dir_name,'shp')
+                gdf = gdf.to_crs(epsg=4326)
+                geoJsonPath = os.path.join(directory,f"{fileName}.geojson")
+                safe_excel_save(gdf,geoJsonPath)
+                self.file_manager[dir_name]['geojson'] = geoJsonPath
+        return geoJsonPath
     def get_file_path(self,dir_name,file_type):
         if dir_name == None:
             dir_name = list(self.file_manager.keys())
@@ -81,6 +96,9 @@ def get_dbf(dir_name=None,file_path="dbf"):
 def get_shx(dir_name=None,file_path="shx"):
     land_mgr = landManager.get_instance()
     return land_mgr.get_contents(dir_name,file_path)
+def get_geojson(dir_name=None,file_path="geojson"):
+    land_mgr = landManager.get_instance()
+    return land_mgr.get_contents(dir_name,file_path)
 def get_bp(bp,column=None,value=None,index=1):
     if isinstance(bp,Polygon) or isinstance(bp,MultiPolygon):
         return bp
