@@ -10,8 +10,11 @@ from werkzeug.datastructures import FileStorage
 import logging
 # Configure logging at the start of your script or application
 logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s - %(message)s')
-def source_ext():
-    return {'.parquet':'pyarrow','.txt':'python','.xlsx':'openpyxl','.xls':'openpyxl','.xlsb':'pyxlsb','.ods':'odf'}
+def source_ext(typ=None):
+    source_js = {'.parquet':'pyarrow','.txt':'python','.xlsx':'openpyxl','.xls':'openpyxl','.xlsb':'pyxlsb','.ods':'odf','.geojson':'GeoJSON'}
+    if typ:
+        source_js = source_js.get(typ)
+    return source_js
 def isDataFrame(obj):
     return isinstance(obj, pd.DataFrame)
 def create_dataframe(new_data=None,columns=None):
@@ -79,7 +82,7 @@ def count_rows_in_excel(data_source, sheet_name=None):
         print("Invalid input. Please provide a valid file path or pandas DataFrame.")
         return None
 
-def get_df(source=None, nrows=None, header='infer', skiprows=None, condition=None, indices=None):
+def get_df(source=None, nrows=None, skiprows=None, condition=None, indices=None):
     """
     Load a DataFrame from various sources with optional filtering.
 
@@ -108,19 +111,19 @@ def get_df(source=None, nrows=None, header='infer', skiprows=None, condition=Non
             logging.info(f"Loading data from file with extension: {file_ext}")
             if file_ext in ['.csv', '.tsv', '.txt']:
                 sep = {'csv': ',', 'tsv': '\t'}.get(file_ext.strip('.'), None)
-                df = pd.read_csv(source, header=header, skiprows=skiprows, sep=sep, nrows=nrows)
+                df = pd.read_csv(source,  skiprows=skiprows, sep=sep, nrows=nrows)
             elif file_ext in ['.ods', '.xlsx', '.xls', '.xlsb']:
                 engine = {'ods': 'odf', 'xlsx': 'openpyxl', 'xls': 'xlrd', 'xlsb': 'pyxlsb'}.get(file_ext.strip('.'))
-                df = pd.read_excel(source, header=header, skiprows=skiprows, engine=engine, nrows=nrows)
+                df = pd.read_excel(source,  skiprows=skiprows, engine=engine, nrows=nrows)
             elif file_ext == '.json':
                 df = pd.read_json(source, nrows=nrows)
             elif file_ext == '.parquet':
                 df = pd.read_parquet(source, nrows=nrows)
-            elif file_ext in ['.shp', '.cpg', '.dbf', '.shx', '.prj']:
-                df = gpd.read_file(source)
+            elif file_ext in ['.shp', '.cpg', '.dbf', '.shx', '.prj','.geojson']:
+                df = gpd.read_file(source,driver=source_ext(file_ext))
             else:
                 raise ValueError(f"Unsupported file extension: {file_ext}")
-            return df
+            return filter_df(df, nrows=nrows, condition=condition, indices=indices)
         except Exception as e:
             logging.error(f"Failed to read file: {e}")
             return None
@@ -129,7 +132,7 @@ def get_df(source=None, nrows=None, header='infer', skiprows=None, condition=Non
         try:
             logging.info(f"Reading from FileStorage: {secure_filename(source.filename)}")
             df = pd.read_excel(source.stream, nrows=nrows)
-            return df
+            return filter_df(df, nrows=nrows, condition=condition, indices=indices)
         except Exception as e:
             logging.error(f"Failed to read from FileStorage: {e}")
             return None
@@ -137,7 +140,8 @@ def get_df(source=None, nrows=None, header='infer', skiprows=None, condition=Non
     if isinstance(source, (dict, list)):
         logging.info("Creating DataFrame from in-memory data structure.")
         df = pd.DataFrame(source)
-        return df
+        return filter_df(df, nrows=nrows, condition=condition, indices=indices)
+
     logging.error("Invalid data source type provided.")
     return None
 
