@@ -65,7 +65,7 @@ def save_df(df,file_path,index=None,suffix=None,engine=None):
 def safe_excel_save(df,original_file_path,index=False,suffix=None,engine=None):
     with tempfile.NamedTemporaryFile(delete=False, suffix=suffix) as tmp:
         temp_file_name = tmp.name
-        result = save_df(df,file_path,index=index,suffix=suffix,engine=engine)  # Save your DataFrame to the temp file
+        result = save_df(df,original_file_path,index=index,suffix=suffix,engine=engine)  # Save your DataFrame to the temp file
     if result and os.path.getsize(temp_file_name) > 0:
         shutil.move(temp_file_name, original_file_path)
     else:
